#[non_exhaustive]pub struct GetTelemetryRuleOutputBuilder { /* private fields */ }Expand description
A builder for GetTelemetryRuleOutput.
Implementations
Sourceimpl GetTelemetryRuleOutputBuilder
impl GetTelemetryRuleOutputBuilder
Sourcepub fn set_rule_name(self, input: Option<String>) -> Self
pub fn set_rule_name(self, input: Option<String>) -> Self
The name of the telemetry rule.
Sourcepub fn get_rule_name(&self) -> &Option<String>
pub fn get_rule_name(&self) -> &Option<String>
The name of the telemetry rule.
Sourcepub fn rule_arn(self, input: impl Into<String>) -> Self
pub fn rule_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the telemetry rule.
Sourcepub fn set_rule_arn(self, input: Option<String>) -> Self
pub fn set_rule_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the telemetry rule.
Sourcepub fn get_rule_arn(&self) -> &Option<String>
pub fn get_rule_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the telemetry rule.
Sourcepub fn created_time_stamp(self, input: i64) -> Self
pub fn created_time_stamp(self, input: i64) -> Self
The timestamp when the telemetry rule was created.
Sourcepub fn set_created_time_stamp(self, input: Option<i64>) -> Self
pub fn set_created_time_stamp(self, input: Option<i64>) -> Self
The timestamp when the telemetry rule was created.
Sourcepub fn get_created_time_stamp(&self) -> &Option<i64>
pub fn get_created_time_stamp(&self) -> &Option<i64>
The timestamp when the telemetry rule was created.
Sourcepub fn last_update_time_stamp(self, input: i64) -> Self
pub fn last_update_time_stamp(self, input: i64) -> Self
The timestamp when the telemetry rule was last updated.
Sourcepub fn set_last_update_time_stamp(self, input: Option<i64>) -> Self
pub fn set_last_update_time_stamp(self, input: Option<i64>) -> Self
The timestamp when the telemetry rule was last updated.
Sourcepub fn get_last_update_time_stamp(&self) -> &Option<i64>
pub fn get_last_update_time_stamp(&self) -> &Option<i64>
The timestamp when the telemetry rule was last updated.
Sourcepub fn telemetry_rule(self, input: TelemetryRule) -> Self
pub fn telemetry_rule(self, input: TelemetryRule) -> Self
The configuration details of the telemetry rule.
Sourcepub fn set_telemetry_rule(self, input: Option<TelemetryRule>) -> Self
pub fn set_telemetry_rule(self, input: Option<TelemetryRule>) -> Self
The configuration details of the telemetry rule.
Sourcepub fn get_telemetry_rule(&self) -> &Option<TelemetryRule>
pub fn get_telemetry_rule(&self) -> &Option<TelemetryRule>
The configuration details of the telemetry rule.
Sourcepub fn home_region(self, input: impl Into<String>) -> Self
pub fn home_region(self, input: impl Into<String>) -> Self
The Amazon Web Services Region where the telemetry rule was originally created. For replicated rules in spoke regions, this indicates the region that manages the rule. For rules created without multi-region scope, this field is not present.
Sourcepub fn set_home_region(self, input: Option<String>) -> Self
pub fn set_home_region(self, input: Option<String>) -> Self
The Amazon Web Services Region where the telemetry rule was originally created. For replicated rules in spoke regions, this indicates the region that manages the rule. For rules created without multi-region scope, this field is not present.
Sourcepub fn get_home_region(&self) -> &Option<String>
pub fn get_home_region(&self) -> &Option<String>
The Amazon Web Services Region where the telemetry rule was originally created. For replicated rules in spoke regions, this indicates the region that manages the rule. For rules created without multi-region scope, this field is not present.
Sourcepub fn is_replicated(self, input: bool) -> Self
pub fn is_replicated(self, input: bool) -> Self
Indicates whether this telemetry rule is a replica that was created in this region through multi-region fan-out from the home region. Replicated rules cannot be directly updated or deleted in the spoke region. To modify a replicated rule, make changes in the home region.
Sourcepub fn set_is_replicated(self, input: Option<bool>) -> Self
pub fn set_is_replicated(self, input: Option<bool>) -> Self
Indicates whether this telemetry rule is a replica that was created in this region through multi-region fan-out from the home region. Replicated rules cannot be directly updated or deleted in the spoke region. To modify a replicated rule, make changes in the home region.
Sourcepub fn get_is_replicated(&self) -> &Option<bool>
pub fn get_is_replicated(&self) -> &Option<bool>
Indicates whether this telemetry rule is a replica that was created in this region through multi-region fan-out from the home region. Replicated rules cannot be directly updated or deleted in the spoke region. To modify a replicated rule, make changes in the home region.
Sourcepub fn region_statuses(self, input: RegionStatus) -> Self
pub fn region_statuses(self, input: RegionStatus) -> Self
Appends an item to region_statuses.
To override the contents of this collection use set_region_statuses.
A list of per-region replication statuses for the telemetry rule. Each entry indicates the replication status of the rule in a specific spoke region. This field is only present for rules created with multi-region scope.
Sourcepub fn set_region_statuses(self, input: Option<Vec<RegionStatus>>) -> Self
pub fn set_region_statuses(self, input: Option<Vec<RegionStatus>>) -> Self
A list of per-region replication statuses for the telemetry rule. Each entry indicates the replication status of the rule in a specific spoke region. This field is only present for rules created with multi-region scope.
Sourcepub fn get_region_statuses(&self) -> &Option<Vec<RegionStatus>>
pub fn get_region_statuses(&self) -> &Option<Vec<RegionStatus>>
A list of per-region replication statuses for the telemetry rule. Each entry indicates the replication status of the rule in a specific spoke region. This field is only present for rules created with multi-region scope.
Sourcepub fn build(self) -> GetTelemetryRuleOutput
pub fn build(self) -> GetTelemetryRuleOutput
Consumes the builder and constructs a GetTelemetryRuleOutput.