#[non_exhaustive]pub struct GetTelemetryRuleOutput {
pub rule_name: Option<String>,
pub rule_arn: Option<String>,
pub created_time_stamp: Option<i64>,
pub last_update_time_stamp: Option<i64>,
pub telemetry_rule: Option<TelemetryRule>,
pub home_region: Option<String>,
pub is_replicated: Option<bool>,
pub region_statuses: Option<Vec<RegionStatus>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rule_name: Option<String>The name of the telemetry rule.
rule_arn: Option<String>The Amazon Resource Name (ARN) of the telemetry rule.
created_time_stamp: Option<i64>The timestamp when the telemetry rule was created.
last_update_time_stamp: Option<i64>The timestamp when the telemetry rule was last updated.
telemetry_rule: Option<TelemetryRule>The configuration details of the telemetry rule.
home_region: Option<String>The Amazon Web Services Region where the telemetry rule was originally created. For replicated rules in spoke regions, this indicates the region that manages the rule. For rules created without multi-region scope, this field is not present.
is_replicated: Option<bool>Indicates whether this telemetry rule is a replica that was created in this region through multi-region fan-out from the home region. Replicated rules cannot be directly updated or deleted in the spoke region. To modify a replicated rule, make changes in the home region.
region_statuses: Option<Vec<RegionStatus>>A list of per-region replication statuses for the telemetry rule. Each entry indicates the replication status of the rule in a specific spoke region. This field is only present for rules created with multi-region scope.
Implementations
Sourceimpl GetTelemetryRuleOutput
impl GetTelemetryRuleOutput
Sourcepub fn created_time_stamp(&self) -> Option<i64>
pub fn created_time_stamp(&self) -> Option<i64>
The timestamp when the telemetry rule was created.
Sourcepub fn last_update_time_stamp(&self) -> Option<i64>
pub fn last_update_time_stamp(&self) -> Option<i64>
The timestamp when the telemetry rule was last updated.
Sourcepub fn telemetry_rule(&self) -> Option<&TelemetryRule>
pub fn telemetry_rule(&self) -> Option<&TelemetryRule>
The configuration details of the telemetry rule.
Sourcepub fn home_region(&self) -> Option<&str>
pub fn home_region(&self) -> Option<&str>
The Amazon Web Services Region where the telemetry rule was originally created. For replicated rules in spoke regions, this indicates the region that manages the rule. For rules created without multi-region scope, this field is not present.
Sourcepub fn is_replicated(&self) -> Option<bool>
pub fn is_replicated(&self) -> Option<bool>
Indicates whether this telemetry rule is a replica that was created in this region through multi-region fan-out from the home region. Replicated rules cannot be directly updated or deleted in the spoke region. To modify a replicated rule, make changes in the home region.
Sourcepub fn region_statuses(&self) -> &[RegionStatus]
pub fn region_statuses(&self) -> &[RegionStatus]
A list of per-region replication statuses for the telemetry rule. Each entry indicates the replication status of the rule in a specific spoke region. This field is only present for rules created with multi-region scope.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .region_statuses.is_none().
Sourceimpl GetTelemetryRuleOutput
impl GetTelemetryRuleOutput
Sourcepub fn builder() -> GetTelemetryRuleOutputBuilder
pub fn builder() -> GetTelemetryRuleOutputBuilder
Creates a new builder-style object to manufacture GetTelemetryRuleOutput.