#[non_exhaustive]pub struct StartTelemetryEvaluationInput {
pub regions: Option<Vec<String>>,
pub all_regions: Option<bool>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.regions: Option<Vec<String>>An optional list of Amazon Web Services Regions to include in multi-region telemetry evaluation. The current region is always implicitly included and must not be specified in this list. When provided, telemetry evaluation starts in the current region and propagates to all specified regions. Mutually exclusive with AllRegions. If neither Regions nor AllRegions is provided, the operation applies only to the current region.
all_regions: Option<bool>If set to true, telemetry evaluation starts in all Amazon Web Services Regions where Amazon CloudWatch Observability Admin is available in the current partition. The current region becomes the home region for managing multi-region evaluation. When new regions become available, evaluation automatically expands to include them. Mutually exclusive with Regions.
Implementations
Sourceimpl StartTelemetryEvaluationInput
impl StartTelemetryEvaluationInput
Sourcepub fn regions(&self) -> &[String]
pub fn regions(&self) -> &[String]
An optional list of Amazon Web Services Regions to include in multi-region telemetry evaluation. The current region is always implicitly included and must not be specified in this list. When provided, telemetry evaluation starts in the current region and propagates to all specified regions. Mutually exclusive with AllRegions. If neither Regions nor AllRegions is provided, the operation applies only to the current region.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .regions.is_none().
Sourcepub fn all_regions(&self) -> Option<bool>
pub fn all_regions(&self) -> Option<bool>
If set to true, telemetry evaluation starts in all Amazon Web Services Regions where Amazon CloudWatch Observability Admin is available in the current partition. The current region becomes the home region for managing multi-region evaluation. When new regions become available, evaluation automatically expands to include them. Mutually exclusive with Regions.
Sourceimpl StartTelemetryEvaluationInput
impl StartTelemetryEvaluationInput
Sourcepub fn builder() -> StartTelemetryEvaluationInputBuilder
pub fn builder() -> StartTelemetryEvaluationInputBuilder
Creates a new builder-style object to manufacture StartTelemetryEvaluationInput.