#[non_exhaustive]pub struct DestinationMetricsConfigurationBuilder { /* private fields */ }Expand description
A builder for DestinationMetricsConfiguration.
Implementations
Sourceimpl DestinationMetricsConfigurationBuilder
impl DestinationMetricsConfigurationBuilder
Sourcepub fn backup_configuration(self, input: MetricsBackupConfiguration) -> Self
pub fn backup_configuration(self, input: MetricsBackupConfiguration) -> Self
Configuration defining the backup region for the metrics backup destination.
Sourcepub fn set_backup_configuration(
self,
input: Option<MetricsBackupConfiguration>,
) -> Self
pub fn set_backup_configuration( self, input: Option<MetricsBackupConfiguration>, ) -> Self
Configuration defining the backup region for the metrics backup destination.
Sourcepub fn get_backup_configuration(&self) -> &Option<MetricsBackupConfiguration>
pub fn get_backup_configuration(&self) -> &Option<MetricsBackupConfiguration>
Configuration defining the backup region for the metrics backup destination.
Sourcepub fn build(self) -> DestinationMetricsConfiguration
pub fn build(self) -> DestinationMetricsConfiguration
Consumes the builder and constructs a DestinationMetricsConfiguration.