#[non_exhaustive]pub struct LogGroupNameConfigurationBuilder { /* private fields */ }Expand description
A builder for LogGroupNameConfiguration.
Implementations
Sourceimpl LogGroupNameConfigurationBuilder
impl LogGroupNameConfigurationBuilder
Sourcepub fn log_group_name_pattern(self, input: impl Into<String>) -> Self
pub fn log_group_name_pattern(self, input: impl Into<String>) -> Self
The pattern used to generate destination log group names during centralization. The pattern can contain static text and dynamic variables that are replaced with source attributes. If a variable cannot be resolved, it inherits the value from its parent variable in the hierarchy. The pattern must be between 1 and 512 characters.
Supported variables:
-
${source.logGroup} — The original log group name from the source account.
-
${source.accountId} — The AWS account ID where the log originated.
-
${source.region} — The AWS Region where the log originated.
-
${source.org.id} — The AWS Organization ID of the source account.
-
${source.org.ouId} — The organizational unit ID of the source account.
-
${source.org.rootId} — The organization Root ID.
-
${source.org.path} — The organizational path from account to root.
Sourcepub fn set_log_group_name_pattern(self, input: Option<String>) -> Self
pub fn set_log_group_name_pattern(self, input: Option<String>) -> Self
The pattern used to generate destination log group names during centralization. The pattern can contain static text and dynamic variables that are replaced with source attributes. If a variable cannot be resolved, it inherits the value from its parent variable in the hierarchy. The pattern must be between 1 and 512 characters.
Supported variables:
-
${source.logGroup} — The original log group name from the source account.
-
${source.accountId} — The AWS account ID where the log originated.
-
${source.region} — The AWS Region where the log originated.
-
${source.org.id} — The AWS Organization ID of the source account.
-
${source.org.ouId} — The organizational unit ID of the source account.
-
${source.org.rootId} — The organization Root ID.
-
${source.org.path} — The organizational path from account to root.
Sourcepub fn get_log_group_name_pattern(&self) -> &Option<String>
pub fn get_log_group_name_pattern(&self) -> &Option<String>
The pattern used to generate destination log group names during centralization. The pattern can contain static text and dynamic variables that are replaced with source attributes. If a variable cannot be resolved, it inherits the value from its parent variable in the hierarchy. The pattern must be between 1 and 512 characters.
Supported variables:
-
${source.logGroup} — The original log group name from the source account.
-
${source.accountId} — The AWS account ID where the log originated.
-
${source.region} — The AWS Region where the log originated.
-
${source.org.id} — The AWS Organization ID of the source account.
-
${source.org.ouId} — The organizational unit ID of the source account.
-
${source.org.rootId} — The organization Root ID.
-
${source.org.path} — The organizational path from account to root.
Sourcepub fn build(self) -> Result<LogGroupNameConfiguration, BuildError>
pub fn build(self) -> Result<LogGroupNameConfiguration, BuildError>
Consumes the builder and constructs a LogGroupNameConfiguration.
This method will fail if any of the following fields are not set: