#[non_exhaustive]pub struct RegionStatusBuilder { /* private fields */ }Expand description
A builder for RegionStatus.
Implementations
Sourceimpl RegionStatusBuilder
impl RegionStatusBuilder
Sourcepub fn region(self, input: impl Into<String>) -> Self
pub fn region(self, input: impl Into<String>) -> Self
The Amazon Web Services Region code (for example, eu-west-1 or us-west-2) that this status applies to.
Sourcepub fn set_region(self, input: Option<String>) -> Self
pub fn set_region(self, input: Option<String>) -> Self
The Amazon Web Services Region code (for example, eu-west-1 or us-west-2) that this status applies to.
Sourcepub fn get_region(&self) -> &Option<String>
pub fn get_region(&self) -> &Option<String>
The Amazon Web Services Region code (for example, eu-west-1 or us-west-2) that this status applies to.
Sourcepub fn status(self, input: impl Into<String>) -> Self
pub fn status(self, input: impl Into<String>) -> Self
The status of the operation in this region. For telemetry evaluation, valid values include STARTING, RUNNING, and FAILED_START. For telemetry rules, valid values include PENDING, ACTIVE, and FAILED.
Sourcepub fn set_status(self, input: Option<String>) -> Self
pub fn set_status(self, input: Option<String>) -> Self
The status of the operation in this region. For telemetry evaluation, valid values include STARTING, RUNNING, and FAILED_START. For telemetry rules, valid values include PENDING, ACTIVE, and FAILED.
Sourcepub fn get_status(&self) -> &Option<String>
pub fn get_status(&self) -> &Option<String>
The status of the operation in this region. For telemetry evaluation, valid values include STARTING, RUNNING, and FAILED_START. For telemetry rules, valid values include PENDING, ACTIVE, and FAILED.
Sourcepub fn failure_reason(self, input: impl Into<String>) -> Self
pub fn failure_reason(self, input: impl Into<String>) -> Self
The reason for a failure status in this region. This field is only populated when Status indicates a failure.
Sourcepub fn set_failure_reason(self, input: Option<String>) -> Self
pub fn set_failure_reason(self, input: Option<String>) -> Self
The reason for a failure status in this region. This field is only populated when Status indicates a failure.
Sourcepub fn get_failure_reason(&self) -> &Option<String>
pub fn get_failure_reason(&self) -> &Option<String>
The reason for a failure status in this region. This field is only populated when Status indicates a failure.
Sourcepub fn rule_arn(self, input: impl Into<String>) -> Self
pub fn rule_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the telemetry rule in this spoke region. This field is only present for telemetry rule region statuses and is populated when the rule has been successfully created in the spoke region (status is ACTIVE).
Sourcepub fn set_rule_arn(self, input: Option<String>) -> Self
pub fn set_rule_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the telemetry rule in this spoke region. This field is only present for telemetry rule region statuses and is populated when the rule has been successfully created in the spoke region (status is ACTIVE).
Sourcepub fn get_rule_arn(&self) -> &Option<String>
pub fn get_rule_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the telemetry rule in this spoke region. This field is only present for telemetry rule region statuses and is populated when the rule has been successfully created in the spoke region (status is ACTIVE).
Sourcepub fn build(self) -> RegionStatus
pub fn build(self) -> RegionStatus
Consumes the builder and constructs a RegionStatus.