#[non_exhaustive]pub struct SourceMetricsConfigurationBuilder { /* private fields */ }Expand description
A builder for SourceMetricsConfiguration.
Implementations
Sourceimpl SourceMetricsConfigurationBuilder
impl SourceMetricsConfigurationBuilder
Sourcepub fn metrics_selection_criteria(self, input: impl Into<String>) -> Self
pub fn metrics_selection_criteria(self, input: impl Into<String>) -> Self
The filter expression that selects which source metrics to centralize. Currently, only * (all metrics) is supported. Other values return a validation error.
Sourcepub fn set_metrics_selection_criteria(self, input: Option<String>) -> Self
pub fn set_metrics_selection_criteria(self, input: Option<String>) -> Self
The filter expression that selects which source metrics to centralize. Currently, only * (all metrics) is supported. Other values return a validation error.
Sourcepub fn get_metrics_selection_criteria(&self) -> &Option<String>
pub fn get_metrics_selection_criteria(&self) -> &Option<String>
The filter expression that selects which source metrics to centralize. Currently, only * (all metrics) is supported. Other values return a validation error.
Sourcepub fn build(self) -> SourceMetricsConfiguration
pub fn build(self) -> SourceMetricsConfiguration
Consumes the builder and constructs a SourceMetricsConfiguration.