#[non_exhaustive]pub enum EncryptionScope {
EncryptedSourceOnly,
NewDestinationLogGroups,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against EncryptionScope, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let encryptionscope = unimplemented!();
match encryptionscope {
EncryptionScope::EncryptedSourceOnly => { /* ... */ },
EncryptionScope::NewDestinationLogGroups => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when encryptionscope represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant EncryptionScope::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
EncryptionScope::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant EncryptionScope::NewFeature is defined.
Specifically, when encryptionscope represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on EncryptionScope::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Determines which newly created destination log groups are encrypted with the configured KMS key.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EncryptedSourceOnly
Only destination log groups whose source log group is encrypted with a customer managed KMS key use the configured KmsKeyArn. This is the default behavior.
NewDestinationLogGroups
Every new destination log group created by this rule uses the configured KmsKeyArn, regardless of whether the source log group is encrypted with a customer managed key or Amazon Web Services owned encryption.
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations
Sourceimpl EncryptionScope
impl EncryptionScope
Sourcepub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
pub fn try_parse(value: &str) -> Result<Self, UnknownVariantError>
Parses the enum value while disallowing unknown variants.
Unknown variants will result in an error.