#[non_exhaustive]pub struct DestinationMetricsConfiguration {
pub backup_configuration: Option<MetricsBackupConfiguration>,
}Expand description
Configuration for centralization destination metrics, including backup settings.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.backup_configuration: Option<MetricsBackupConfiguration>Configuration defining the backup region for the metrics backup destination.
Implementations
Sourceimpl DestinationMetricsConfiguration
impl DestinationMetricsConfiguration
Sourcepub fn backup_configuration(&self) -> Option<&MetricsBackupConfiguration>
pub fn backup_configuration(&self) -> Option<&MetricsBackupConfiguration>
Configuration defining the backup region for the metrics backup destination.
Sourceimpl DestinationMetricsConfiguration
impl DestinationMetricsConfiguration
Sourcepub fn builder() -> DestinationMetricsConfigurationBuilder
pub fn builder() -> DestinationMetricsConfigurationBuilder
Creates a new builder-style object to manufacture DestinationMetricsConfiguration.