#[non_exhaustive]pub struct RegionStatus {
pub region: Option<String>,
pub status: Option<String>,
pub failure_reason: Option<String>,
pub rule_arn: Option<String>,
}Expand description
Represents the status of a multi-region operation in a specific Amazon Web Services Region. This structure is used to report per-region progress for both telemetry evaluation and telemetry rule replication.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.region: Option<String>The Amazon Web Services Region code (for example, eu-west-1 or us-west-2) that this status applies to.
status: Option<String>The status of the operation in this region. For telemetry evaluation, valid values include STARTING, RUNNING, and FAILED_START. For telemetry rules, valid values include PENDING, ACTIVE, and FAILED.
failure_reason: Option<String>The reason for a failure status in this region. This field is only populated when Status indicates a failure.
rule_arn: Option<String>The Amazon Resource Name (ARN) of the telemetry rule in this spoke region. This field is only present for telemetry rule region statuses and is populated when the rule has been successfully created in the spoke region (status is ACTIVE).
Implementations
Sourceimpl RegionStatus
impl RegionStatus
Sourcepub fn region(&self) -> Option<&str>
pub fn region(&self) -> Option<&str>
The Amazon Web Services Region code (for example, eu-west-1 or us-west-2) that this status applies to.
Sourcepub fn status(&self) -> Option<&str>
pub fn status(&self) -> Option<&str>
The status of the operation in this region. For telemetry evaluation, valid values include STARTING, RUNNING, and FAILED_START. For telemetry rules, valid values include PENDING, ACTIVE, and FAILED.
Sourcepub fn failure_reason(&self) -> Option<&str>
pub fn failure_reason(&self) -> Option<&str>
The reason for a failure status in this region. This field is only populated when Status indicates a failure.
Sourceimpl RegionStatus
impl RegionStatus
Sourcepub fn builder() -> RegionStatusBuilder
pub fn builder() -> RegionStatusBuilder
Creates a new builder-style object to manufacture RegionStatus.